@@ -1,4 +1,4 @@
-from .query import get_filtration, set_default_filtration_class
+from .query import get_filtration
 from .filtration import FiltrationData, ParsingData
 from .table import DataTable
 from .operations import FiltrationOperator
@@ -6,7 +6,6 @@ from .schemas import Filterable, Filter
 
 __all__ = [
     "get_filtration",
-    "set_default_filtration_class",
     "ParsingData",
     "DataTable",
     "FiltrationData",
