@@ -145,6 +145,7 @@ class ParsingData:
 
 
 class FiltrationData(BaseModel):
+    default_model: Optional[str] = None
     to_filter: ParsingData = ParsingData()
     page_number: int = 1
     page_size: int = Field(
@@ -188,9 +189,18 @@ class FiltrationData(BaseModel):
         cls._default[attr] = value
 
     def __get_sort_spec(self) -> list[ModelSortSpec]:
-        return [_split_field(self.order_by) | {"direction": self.sort_by}]  # type: ignore
+        if self.order_by is None:
+            raise ValueError("order_by is None, can not get a sort spec.")
+
+        res = _split_field(self.order_by) | {"direction": self.sort_by}
+        if "model" not in res and self.default_model is not None:
+            res |= {"model": self.default_model}
+        return [res]  # type: ignore
 
     def apply(self, query: Query) -> DataTable:
+        if self.default_model is not None:
+            self.to_filter = self.to_filter.set_default_model(self.default_model)
+
         filter_spec = self.to_filter.to_spec()
         if filter_spec != {}:
             query = apply_filters(query, filter_spec)
