@@ -266,13 +266,13 @@ def get_filtration(
                 detail=f"order_by = {order_by!r} is not a valid column. "
                 f"Valid columns: {', '.join(valid_columns)}",
             )
-        parsing_data = parser.parse(request.query_params)
-        if default_model is not None:
-            parsing_data = parsing_data.set_default_model(default_model)
-            if "." not in order_by:
-                order_by = f"{default_model}.{order_by}"
 
-        _kwargs: dict[str, Any] = dict(to_filter=parsing_data, sort_by=sort_by)
+        _kwargs: dict[str, Any] = dict(
+            to_filter=parser.parse(request.query_params),
+            sort_by=sort_by,
+            default_model=default_model,
+        )
+
         if page_number is not None:
             _kwargs["page_number"] = page_number
         if page_size is not None:
